@@ -17,8 +17,8 @@
 #include <rudiments/regularexpression.h>
 #include <rudiments/sharedmemory.h>
 #include <rudiments/semaphoreset.h>
-#include <authenticator.h>
 
+#include <authenticator.h>
 #include <debugfile.h>
 #include <tempdir.h>
 
@@ -28,6 +28,10 @@
 
 #include <defines.h>
 
+#ifdef RUDIMENTS_NAMESPACE
+using namespace rudiments;
+#endif
+
 class sqlrconnection : public daemonprocess, public listener, public debugfile {
 	friend class sqlrcursor;
 	public:
@@ -52,9 +56,9 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 		virtual bool	autoCommitOff();
 		virtual bool	commit();
 		virtual bool	rollback();
-		virtual char	*pingQuery();
-		virtual bool	ping();
-		virtual char	*identify()=0;
+		virtual const char	*pingQuery();
+		virtual bool		ping();
+		virtual const char	*identify()=0;
 		virtual sqlrcursor	*initCursor()=0;
 		virtual void	deleteCursor(sqlrcursor *curs)=0;
 		virtual	short	nonNullBindValue();
@@ -66,8 +70,8 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 		virtual bool	isTransactional();
 		virtual void	setUser(const char *user);
 		virtual void	setPassword(const char *password);
-		virtual char	*getUser();
-		virtual char	*getPassword();
+		virtual const char	*getUser();
+		virtual const char	*getPassword();
 		virtual void	dropTempTables(sqlrcursor *cursor,
 						stringlist *tablelist);
 		virtual void	dropTempTable(sqlrcursor *cursor,
@@ -79,14 +83,14 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 
 	public:
 		// methods used by derived classes
-		char	*connectStringValue(const char *variable);
-		void	setAutoCommitBehavior(bool ac);
-		bool	getAutoCommitBehavior();
-		bool	sendColumnInfo();
-		void	sendRowCounts(long actual, long affected);
-		void	sendColumnCount(unsigned long ncols);
-		void	sendColumnTypeFormat(unsigned short format);
-		void	sendColumnDefinition(const char *name, 
+		const char	*connectStringValue(const char *variable);
+		void		setAutoCommitBehavior(bool ac);
+		bool		getAutoCommitBehavior();
+		bool		sendColumnInfo();
+		void		sendRowCounts(long actual, long affected);
+		void		sendColumnCount(unsigned long ncols);
+		void		sendColumnTypeFormat(unsigned short format);
+		void		sendColumnDefinition(const char *name, 
 						unsigned short namelen, 
 						unsigned short type, 
 						unsigned long size,
@@ -100,7 +104,7 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 						unsigned short zerofill,
 						unsigned short binary,
 						unsigned short autoincrement);
-		void	sendColumnDefinitionString(const char *name, 
+		void		sendColumnDefinitionString(const char *name, 
 						unsigned short namelen, 
 						const char *type, 
 						unsigned short typelen, 
@@ -115,15 +119,20 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 						unsigned short zerofill,
 						unsigned short binary,
 						unsigned short autoincrement);
-		void	sendField(const char *data, unsigned long size);
-		void	sendNullField();
-		void	startSendingLong();
-		void	sendLongSegment(const char *data, unsigned long size);
-		void	endSendingLong();
-		void	addSessionTempTableForDrop(const char *tablename);
-		void	addSessionTempTableForTrunc(const char *tablename);
-		void	addTransactionTempTableForDrop(const char *tablename);
-		void	addTransactionTempTableForTrunc(const char *tablename);
+		void		sendField(const char *data, unsigned long size);
+		void		sendNullField();
+		void		startSendingLong();
+		void		sendLongSegment(const char *data,
+						unsigned long size);
+		void		endSendingLong();
+		void		addSessionTempTableForDrop(
+						const char *tablename);
+		void		addSessionTempTableForTrunc(
+						const char *tablename);
+		void		addTransactionTempTableForDrop(
+						const char *tablename);
+		void		addTransactionTempTableForTrunc(
+						const char *tablename);
 
 	private:
 		// methods used internally
@@ -132,23 +141,29 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 		void	incrementConnectionCount();
 		void	decrementConnectionCount();
 		void	decrementSessionCount();
-		void	announceAvailability(char *tmpdir,
+		void	announceAvailability(const char *tmpdir,
 					bool passdescriptor,
-					char *unixsocket,
+					const char *unixsocket,
 					unsigned short inetport,
-					char *connectionid);
-		void	registerForHandoff(char *tmpdir);
+					const char *connectionid);
+		void	registerForHandoff(const char *tmpdir);
 		bool	receiveFileDescriptor(int *descriptor);
-		void	deRegisterForHandoff(char *tmpdir);
-		bool	getUnixSocket(char *tmpdir, char *unixsocketptr);
-		int	openSequenceFile(char *tmpdir, char *unixsocketptr);
-		bool	lockSequenceFile();
-		bool	getAndIncrementSequenceNumber(char *unixsocketptr);
-		bool	unLockSequenceFile();
+		void	deRegisterForHandoff(const char *tmpdir);
+		bool	getUnixSocket(const char *tmpdir,
+						char *unixsocketptr);
+		bool	openSequenceFile(file *sockseq,
+						const char *tmpdir,
+						char *unixsocketptr);
+		bool	lockSequenceFile(file *sockseq);
+		bool	getAndIncrementSequenceNumber(file *sockseq,
+							char *unixsocketptr);
+		bool	unLockSequenceFile(file *sockseq);
 
 
-		bool		createSharedMemoryAndSemaphores(char *tmpdir,
-								char *id);
+		bool		createSharedMemoryAndSemaphores(
+							const char *tmpdir,
+							const char *id);
+		void		waitForListenerToRequireAConnection();
 		void		acquireAnnounceMutex();
 		shmdata		*getAnnounceBuffer();
 		void		signalListenerToRead();
@@ -247,6 +262,8 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 		void	setInitialAutoCommitBehavior();
 		bool	openSockets();
 
+		void	flushWriteBuffer();
+
 		cmdline			*cmdl;
 		sqlrconfigfile		*cfgfl;
 
@@ -298,10 +315,8 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 		unixclientsocket	handoffsockun;
 		bool			connected;
 
-		char	*connectionid;
-		int	ttl;
-
-		int	sockseq;
+		const char	*connectionid;
+		int		ttl;
 
 		semaphoreset	*semset;
 		sharedmemory	*idmemory;
