@@ -6,7 +6,6 @@
 
 #include <config.h>
 #include <defaults.h>
-#include <rudiments/signalclasses.h>
 #include <rudiments/daemonprocess.h>
 #include <rudiments/listener.h>
 #include <rudiments/unixserversocket.h>
@@ -14,8 +13,8 @@
 #include <rudiments/filedescriptor.h>
 #include <rudiments/semaphoreset.h>
 #include <rudiments/sharedmemory.h>
-#include <authenticator.h>
 #include <rudiments/regularexpression.h>
+#include <authenticator.h>
 
 #include <cmdline.h>
 #include <debugfile.h>
@@ -26,9 +25,12 @@
 	#include <rudiments/logger.h>
 #endif
 
-
 #include <defines.h>
 
+#ifdef RUDIMENTS_NAMESPACE
+using namespace rudiments;
+#endif
+
 class handoffsocketnode {
 	friend class sqlrlistener;
 	private:
@@ -36,7 +38,7 @@ class handoffsocketnode {
 		filedescriptor		*sock;
 };
 
-class sqlrlistener : public daemonprocess, public listener, public debugfile {
+class sqlrlistener : public daemonprocess, public listener, private debugfile {
 	public:
 			sqlrlistener();
 			~sqlrlistener();
@@ -45,6 +47,8 @@ class sqlrlistener : public daemonprocess, public listener, public debugfile {
 	private:
 		void	cleanUp();
 		void	setUserAndGroup(sqlrconfigfile *cfgfl);
+		bool	verifyAccessToConfigFile(const char *configfile,
+						sqlrconfigfile *cfgfl);
 		bool	handlePidFile(tempdir *tmpdir, const char *id);
 		void	handleDynamicScaling(sqlrconfigfile *cfgfl);
 		void	setHandoffMethod(sqlrconfigfile *cfgfl);
@@ -66,11 +70,10 @@ class sqlrlistener : public daemonprocess, public listener, public debugfile {
 		bool	registerHandoff(filedescriptor *sock);
 		bool	deRegisterHandoff(filedescriptor *sock);
 		bool	fixup(filedescriptor *sock);
-		bool	deniedIp();
-		void	disconnectClient(filedescriptor *sock);
-		void	forkChild(filedescriptor *sock);
-		void	clientSession(filedescriptor *sock);
-		int	getAuth(filedescriptor *sock);
+		bool	deniedIp(filedescriptor *clientsock);
+		void	forkChild(filedescriptor *clientsock);
+		void	clientSession(filedescriptor *clientsock);
+		int	getAuth(filedescriptor *clientsock);
 		void	incrementSessionCount();
 		bool	handOffClient(filedescriptor *sock);
 		void	getAConnection(unsigned long *connectionpid,
@@ -94,7 +97,8 @@ class sqlrlistener : public daemonprocess, public listener, public debugfile {
 					filedescriptor *connectionsock,
 					int fd);
 		void	waitForClientClose(int authstatus, bool passstatus,
-						filedescriptor *sock);
+						filedescriptor *clientsock);
+		void	flushWriteBuffer(filedescriptor *fd);
 
 		bool		passdescriptor;
 
@@ -121,7 +125,7 @@ class sqlrlistener : public daemonprocess, public listener, public debugfile {
 		unixserversocket	*fixupsockun;
 		char			*fixupsockname;
 
-		handoffsocketnode	**handoffsocklist;
+		handoffsocketnode	*handoffsocklist;
 
 		regularexpression	*allowed;
 		regularexpression	*denied;
