@@ -6,6 +6,10 @@
 
 #include <sqlrconfigfile.h>
 
+#ifdef RUDIMENTS_NAMESPACE
+using namespace rudiments;
+#endif
+
 class authenticator {
 
 	public:
