@@ -4,8 +4,8 @@
 # See the file COPYING for more information.
 
 
-use Firstworks::SQLRConnection;
-use Firstworks::SQLRCursor;
+use SQLRelay::Connection;
+use SQLRelay::Cursor;
 
 sub checkUndef {
 
@@ -54,9 +54,9 @@ if ($#ARGV+1<5) {
 
 
 # instantiation
-$con=Firstworks::SQLRConnection->new($ARGV[0],$ARGV[1], 
+$con=SQLRelay::Connection->new($ARGV[0],$ARGV[1], 
 				$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$cur=Firstworks::SQLRCursor->new($con);
+$cur=SQLRelay::Cursor->new($con);
 
 # get database type
 print("IDENTIFY: \n");
@@ -85,6 +85,7 @@ print("\n");
 
 print("BIND BY POSITION: \n");
 $cur->prepareQuery("insert into testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7)");
+checkSuccess($cur->countBindVariables(),7);
 $cur->inputBind("1",2);
 $cur->inputBind("2","testchar2");
 $cur->inputBind("3","testvarchar2");
@@ -691,9 +692,9 @@ $cur->setResultSetBufferSize(0);
 print("\n");
 
 print("COMMIT AND ROLLBACK: \n");
-$secondcon=Firstworks::SQLRConnection->new($ARGV[0],
+$secondcon=SQLRelay::Connection->new($ARGV[0],
 			$ARGV[1],$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$secondcur=Firstworks::SQLRCursor->new($secondcon);
+$secondcur=SQLRelay::Cursor->new($secondcon);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
 checkSuccessString($secondcur->getField(0,0),"0");
 checkSuccess($con->commit(),1);
@@ -768,10 +769,10 @@ $cur->sendQuery("drop table testtable2");
 $cur->sendQuery("create table testtable2 (testclob clob)");
 $cur->prepareQuery("insert into testtable2 values (:clobval)");
 $clobval="";
-for ($i=0; $i<70*1024; $i++) {
+for ($i=0; $i<8*1024; $i++) {
 	$clobval=$clobval.'C';
 }
-$cur->inputBindClob("clobval",$clobval,70*1024);
+$cur->inputBindClob("clobval",$clobval,8*1024);
 checkSuccess($cur->executeQuery(),1);
 $cur->sendQuery("select testclob from testtable2");
 checkSuccess($clobval,$cur->getField(0,"testclob"));
@@ -779,16 +780,16 @@ $cur->prepareQuery("begin select testclob into :clobbindval from testtable2; end
 $cur->defineOutputBindClob("clobbindval");
 checkSuccess($cur->executeQuery(),1);
 $clobbindvar=$cur->getOutputBind("clobbindval");
-checkSuccess($cur->getOutputBindLength("clobbindval"),70*1024);
+checkSuccess($cur->getOutputBindLength("clobbindval"),8*1024);
 checkSuccess($clobval,$clobbindvar);
 $cur->sendQuery("delete from testtable2");
 print("\n");
 $cur->prepareQuery("insert into testtable2 values (:clobval)");
 $clobval="";
-for ($i=0; $i<70*1024; $i++) {
+for ($i=0; $i<8*1024; $i++) {
 	$clobval=$clobval.'C';
 }
-$cur->inputBindClob("clobval",$clobval,70*1024);
+$cur->inputBindClob("clobval",$clobval,8*1024);
 checkSuccess($cur->executeQuery(),1);
 $cur->sendQuery("select testclob from testtable2");
 checkSuccess($clobval,$cur->getField(0,"testclob"));
@@ -796,7 +797,7 @@ $cur->prepareQuery("begin select testclob into :clobbindval from testtable2; end
 $cur->defineOutputBindClob("clobbindval");
 checkSuccess($cur->executeQuery(),1);
 $clobbindvar=$cur->getOutputBind("clobbindval");
-checkSuccess($cur->getOutputBindLength("clobbindval"),70*1024);
+checkSuccess($cur->getOutputBindLength("clobbindval"),8*1024);
 checkSuccess($clobval,$clobbindvar);
 $cur->sendQuery("drop table testtable2");
 print("\n");
